@@ -22,6 +22,8 @@ def play(args):
     try:
         if args.device_location:
             device = util.parse_xml(args.device_location)
+        elif args.query_device:
+            device = list(filter(lambda x: args.query_device in x["friendly_name"], util.get_device(args.timeout)))[0]
         else:
             device = util.get_device(args.timeout)[0]
     except Exception:
@@ -53,10 +55,12 @@ def run():
     p_play = subparsers.add_parser('play')
     p_play.set_defaults(func=play)
     p_play.add_argument("-d", "--device", dest="device_location")
+    p_play.add_argument("-q", "--query", dest="query_device")
+    p_play.add_argument("-t", "--timeout", type=float, default=5)
     p_play.add_argument('src', type=str, help="media src")
 
     try:
         args = parser.parse_args()
         args.func(args)
     except Exception:
-        print("leesoar.com")
+        print("A UPnP/DLNA client, support local file and online resource cast to screen. Powered by leesoar.com")
